#
# spec file for package python-django-storages
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-django-storages
Version:        1.14.4
Release:        1.2
Summary:        Support for many storage backends in Django
License:        BSD-3-Clause
URL:            https://github.com/jschneier/django-storages
Source:         https://files.pythonhosted.org/packages/source/d/django-storages/django-storages-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 3.2
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Django >= 3.2}
BuildRequires:  %{python_module azure-storage-blob >= 12}
BuildRequires:  %{python_module boto3 >= 1.4.4}
BuildRequires:  %{python_module dropbox >= 7.2.1}
BuildRequires:  %{python_module google-cloud-storage >= 1.27}
BuildRequires:  %{python_module paramiko >= 1.15}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
django-storages is a project to provide a variety of storage backends in a single library.

%prep
%setup -q -n django-storages-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export PYTHONPATH=.
export DJANGO_SETTINGS_MODULE=tests.settings
# Integration tests, which is only azure, fail systematically
rm tests/test_azure.py tests/test_s3.py
# Skip failing test in test_s3boto3.py
%pytest -k 'not test_deprecated_default_acl and not test_with_string_file_detect_encoding'

%files %{python_files}
%doc CHANGELOG.rst README.rst
%license LICENSE
%{python_sitelib}/storages
%{python_sitelib}/django_storages-%{version}.dist-info

%changelog
* Thu Nov  7 2024 Dirk Müller <dmueller@suse.com>
- update to 1.14.4:
  * Pull AWS_SESSION_TOKEN from the environment
  * Fix newline handling for text mode files
  * Do not sign URLs when querystring_auth=False e.g public
    buckets or static files
  * Cache CloudFront Signers
  * Fix collectstatic --clear
  * Add mode kwarg to .url() to support creation of signed URLs
    for upload
  * Fix fetching user delegation key when custom domain is
    enabled
  * Add implementations of get_(modified|accessed)_time
  * Add support for Python 3.12
  * Conform to BaseStorage interface
  * Add FTP_ALLOW_OVERWRITE setting
  * Add support for Django 5.0 and Python 3.12
  * Deprecated: The config class property has been deprecated in
    favor of the client_config setting, a future version will
    remove support for the property.
  * Fix disabling CloudFront signing with class variables
  * Fix AWS_S3_* environment variables lookup
  * Add client_config/AWS_S3_CLIENT_CONFIG to configure advanced
    botocore settings
  * Fix re-gzipping already gzipped files
  * Add SFTP_BASE_URL setting
  * Fix saving files when SFTP_STORAGE_ROOT is set
  * Add support for FTP TLS via ftps URLs
  * Add support for passwords with urlchars
  * Fix re-opening of S3File
  * Revert raising ImproperlyConfigured when no bucket_name is
    set
  * Do not require both AccountName and AccountKey in
    connection_string
  * Work around boto3 closing the uploaded file
  * Fix crash when cleaning up during aborted connection of
    S3File.write
  * Raise FileNotFoundError when attempting to read the size of a
    non-existent file
  * Move auth & CloudFront signer validation to init
  * Raise ImproperlyConfigured if no bucket_name is set
  * Fix tracking of S3File.closed
  * Breaking: Drop support for Django 4.0
  * Breaking: The long deprecated & removed (from Django)
    (modified|created|accessed)_time methods have been removed
    from the various storages, please replace with the
    get_(modified|created|accessed)_time methods
  * Add support for saving pathlib.PurePath names
  * Add support for Django 4.2
  * Set account_(name|key) from connection_string if not provided
  * Deprecated: The name DropboxStorage.location has been
    deprecated, please rename to DropboxStorage.root_path, a
    future version will remove support for the old name.
  * Storage and related names with a captialized B have been
    changed to no longer have one e.g DropboxStorage has now
    replaced DropBoxStorage. Aliases have been added so no change
    is necessary at this time. A future version might deprecate
    the old names.
  * DropboxStorage now conforms to the BaseStorage interface
  * Fix name mangling when saving with certain complex root paths
  * Use setting BASE_URL if it is defined
  * Breaking: Support for the deprecated GS_CACHE_CONTROL has
    been removed. Please set the cache_control parameter of
    GS_OBJECT_PARAMETERS instead.
  * Reading a file that does not exist will now raise
    FileNotFoundError
  * Add closing context manager for standalone usage to ensure
    connections are cleaned up
  * Deprecated: AWS_S3_USE_THREADS has been deprecated in favor
    of AWS_S3_TRANSFER_CONFIG
  * Important: The namespace of this backend has changed from
    S3Boto3 to S3. There are no current plans to deprecate and
    remove the old namespace but please update if you can. All
    paths, imports, and classes that previously referred to
    s3boto are now s3. E.g S3Boto3Storage has been changed to
    S3Storage and S3Boto3StorageFile has been changed to S3File.
    (#1289). Additionally the install extra is now s3
  * Add setting transfer_config/AWS_S3_TRANSFER_CONFIG to
    customize any of the TransferConfig properties
  * Enable passing security_token to constructor
  * Do not overwrite a returned ContentType from
    get_object_parameters
  * Add support for setting cloudfront_key_id and cloudfront_key
    via Django 4.2's OPTIONS
  * Fix S3File.closed
  * Fix opening new files in write mode with S3File
  * Fix S3File not respecting mode on readlines
  * Fix saving files with string content
  * Fix retrieving files with SSE-C enabled
* Tue Apr 23 2024 Georg Pfuetzenreuter <mail+rpm@georg-pfuetzenreuter.net>
- Switch to sle15_python_module_pythons to build for newer Python stack
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to 1.13.2:
  * Add support for Python 3.11 (`#1196`_)
  * Add support for saving ``pathlib.Path`` names (`#1200`_)
  * Catch 404 errors when calling ``delete()`` (`#1201`_)
  * Use ``AZURE_CUSTOM_DOMAIN`` for retrieving blob URLs and storage URL for
    other operations (`#1176`_)
  * Use ``DEFAULT_RETRY`` for all upload & delete operations (`#1156`_)
  * Fix gzipping of content (`#1203`_)
  * Pass through kwargs to signed URL generator (`#1193`_)
  * Improve write & memory performance when saving files (`#1194`_)
  * Strip off the root path when saving files to fix saving with upgraded
    versions of Django (`#1168`_)
  * Update ``DropBoxStorage`` constructor parameter order to be backwards
    compatible (`#1167`_)
  * Add support for Django 4.0 and 4.1 (`#1093`_)
  * Drop support for Django 2.2, 3.0 and 3.1 (`#1093`_)
  * Drop support for Python 3.5 and 3.6 (`#1093`_)
  * **Breaking**: Update and document the undocumented
    ``AWS_S3_URL_PROTOCOL`` from ``http:`` to ``https:`` and remove the
  undocumented ``AWS_S3_SECURE_URLS`` setting. You should only need to update your settings if you had updated either of
  these previously undocumented settings.  The default behavior of constructing an ``https:`` URL with a custom domain
  is unchanged (`#1164`_)
  * Add ``AWS_S3_USE_THREADS`` to disable ``threading`` for compatibility
    with ``gevent`` (`#1112`_)
  * Restore support for ``AZURE_ENDPOINT_SUFFIX`` (`#1118`_)
  * Replace deprecated ``download_to_stream`` with ``readinto`` (`#1113`_)
  * Add ``AZURE_API_VERSION`` setting (`#1132`_)
  * Fix ``get_modified_time()`` (`#1134`_)
* Thu May 12 2022 pgajdos@suse.com
- version update to 1.12.3
  General
  - ------
  - Add support for Python 3.10 (`#1078`_)
  S3
  - -
  - Re-raise non-404 errors in ``.exists()`` (`#1084`_, `#1085`_)
  Azure
  - ----
  - Fix using ``AZURE_CUSTOM_DOMAIN`` with an account key credential (`#1082`_, `#1083`_)
  SFTP
  - ---
  - Catch ``FileNotFoundError`` instead of ``OSerror`` in ``.exists()`` to prevent swallowing ``socket.timeout`` exceptions (`#1064`_, `#1087`_)
  Azure
  - ----
  - Add ``parameters`` kwarg to ``AzureStorage.url`` to configure blob properties in the SAS token (`#1071`_)
  - Fix regression where ``AZURE_CUSTOM_DOMAIN`` was interpreted as a replacement of ``blob.core.windows.net`` rather than as a full domain
    (`#1073`_, `#1076`_)
* Tue Oct 12 2021 ecsos <ecsos@opensuse.org>
- Update to 1.12.1
  * S3
  - Change gzip compression to use a streaming implementation (#1061)
  - Fix saving files with S3ManifestStaticStorage (#1068, #1069)
- Changes from 1.12
  - Add support for Django 3.2 (#1046, #1042, #1005)
  - Replace Travis CI with GitHub actions (#1051)
  * S3
  - Convert signing keys to bytes if necessary (#1003)
  - Avoid a ListParts API call during multipart upload (#1041)
  - Custom domains now use passed URL params (#1054)
  - Allow the use of AWS profiles and clarify the options for
    passing credentials (fbe9538)
  - Re-allow override of various access key names (#1026)
  - Properly exclude empty folders during listdir (66f4f8e)
  - Support saving file objects that are not seekable (#860, #1057)
  - Return True for .exists() if a non-404 error is encountered (#938)
  * Azure
  - Breaking: This backend has been rewritten to use the newer
    versions of azure-storage-blob, which now has a minimum required
    version of 12.0. The settings AZURE_EMULATED_MODE, AZURE_ENDPOINT_SUFFIX,
    and AZURE_CUSTOM_CONNECTION_STRING are now ignored. (#784, #805)
  - Add support for user delegation keys (#1063)
  * Google Cloud
  - Breaking: The minimum required version of google-cloud-storage
    is now 1.27.0 (#994)
  - Breaking: Switch URL signing version from v2 to v4 (#994)
  - Deprecated: Support for GS_CACHE_CONTROL will be removed in 1.13.
    Please set the cache_control parameter of GS_OBJECT_PARAMETERS instead. (#970)
  - Add GS_OBJECT_PARAMETERS and overridable GoogleCloudStorage.get_object_parameters
    to customize blob parameters for all blobs and per-blob respectively. (#970)
  - Catch the NotFound exception raised when deleting a non-existent blob,
    this matches Django and other backends (#998, #999)
  - Fix signing URLs with custom endpoints (#994)
  * Dropbox
  - Validate write_mode param (#1020)
- Changes from 1.11.1
  * S3
  - Revert fix for ValueError: I/O operation on closed file when
    calling collectstatic and introduce S3StaticStorage and
    S3ManifestStaticStorage for use as STATICFILES_STORAGE targets (#968)
- Changes from 1.11
  * General
  - Test against Python 3.9 (#964)
  * S3
  - Fix ValueError: I/O operation on closed file when calling
    collectstatic (#382, #955)
  - Calculate S3Boto3StorageFile.buffer_size (via setting
    AWS_S3_FILE_BUFFER_SIZE) at run-time rather than import-time. (#930)
  - Fix writing bytearray content (#958, #965)
  * Google Cloud
  - Add setting GS_QUERYSTRING_AUTH to avoid signing URLs.
    This is useful for buckets with a policy of Uniform public read (#952)
  * Azure
  - Add AZURE_OBJECT_PARAMETERS and overridable AzureStorage.get_object_parameters
    to customize ContentSettings parameters for all keys and per-key respectively. (#898)
* Fri Nov 27 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v1.10.1
  * Restore AWS_DEFAULT_ACL handling.
    This setting is ignored if ACL is set in AWS_S3_OBJECT_PARAMETERS
  * Fix using SFTP_STORAGE_HOST
- from v1.10
  * Removed support for end-of-life Python 2.7 and 3.4
  * Removed support for end-of-life Django 1.11
  * Add support for Django 3.1
  * Introduce a new BaseStorage class with a get_default_settings
    method and use it in S3Boto3Storage, AzureStorage,
    GoogleCloudStorage, and SFTPStorage. These backends now
    calculate their settings when instantiated, not imported.
  * S3 Breaking: Automatic bucket creation has been removed.
    Doing so encourages using overly broad credentials.
    As a result, support for the corresponding AWS_BUCKET_ACL and
    AWS_AUTO_CREATE_BUCKET settings have been removed.
  * Support for the undocumented setting AWS_PRELOAD_METADATA removed
  * The constructor kwarg acl is no longer accepted. Instead, use the
    ACL key in setting AWS_S3_OBJECT_PARAMETERS
  * The constructor kwarg ``bucket`` is no longer accepted.
    Instead, use ``bucket_name`` or AWS_STORAGE_BUCKET_NAME setting
  * Support for setting AWS_REDUCED_REDUNDANCY has been removed.
    Replace with StorageClass=REDUCED_REDUNDANCY in
    AWS_S3_OBJECT_PARAMETERS
  * Support for setting AWS_S3_ENCRYPTION has been removed.
    Replace with ServerSideEncryption=AES256 in
    AWS_S3_OBJECT_PARAMETERS
  * Support for setting AWS_DEFAULT_ACL has been removed.
    Replace with ACL in AWS_S3_OBJECT_PARAMETERS
  * Add ``http_method`` parameter to ``.url`` method
  * Add support for signing Cloudfront URLs to the ``.url`` method.
    You must set AWS_CLOUDFRONT_KEY, AWS_CLOUDFRONT_KEY_ID and
    install either cryptography or rsa.
    URLs will only be signed if AWS_QUERYSTRING_AUTH is set to True
  * Automatic Google Cloud bucket creation has been removed.
    Doing so encourages using overly broad credentials.
    As a result, support for the corresponding GS_AUTO_CREATE_BUCKET
    and GS_AUTO_CREATE_ACL settings have been removed.
  * Add DROPBOX_WRITE_MODE setting to control e.g. overwriting behavior.
  * Remove SFTP exception swallowing during ssh connection
  * Add FTP_STORAGE_ENCODING setting to set the filesystem encoding
  * Support multiple nested paths for files
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Thu Feb 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.9.1:
  * Breaking: The long deprecated S3 backend based on boto has been removed. (#825)
  * Test against and support Python 3.8 (#810)
* Tue Jan  7 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.8:
  * support for django 3.x
* Mon Sep 16 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.7.2:
  * Various cloud fixes
  * Support for newer django releases
- Drop merged e9bb4bcb8a1b7720468add08bc8343ffbaa0165c.patch
* Thu Apr  4 2019 Ondřej Súkup <mimi.vx@gmail.com>
- add e9bb4bcb8a1b7720468add08bc8343ffbaa0165c.patch for django-2.2
* Sat Feb 16 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v1.7.1
